BaseStep - Qudas 0.2.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# BaseStep

class qudas.pipeline.steps.BaseStep
  get_global_params() → dict

    グローバルパラメータを取得するメソッド。 デフォルトでは空の辞書を返すため、必要なステップだけがオーバーライドする。

    Returns:

      グローバルパラメータの辞書。

    Return type:

      dict

  set_global_params(params: dict) → None

    グローバルパラメータを設定するメソッド。 デフォルトでは何もしないため、必要なステップだけがオーバーライドする。

    Parameters:

      params (dict) – グローバルパラメータの辞書。